Send connman mailing list submissions to
        [email protected]

To subscribe or unsubscribe via email, send a message with subject or
body 'help' to
        [email protected]

You can reach the person managing the list at
        [email protected]

When replying, please edit your Subject line so it is more specific
than "Re: Contents of connman digest..."

Today's Topics:

   1. Re: Next release (Daniel Wagner)
   2. [PATCH] Treewide: fix typos (Torstein Husebø)


----------------------------------------------------------------------

Date: Wed, 22 Jan 2020 14:52:48 +0100
From: Daniel Wagner <[email protected]>
Subject: Re: Next release
To: Richard Röjfors <[email protected]>
Cc: connman <[email protected]>
Message-ID: <[email protected]>
Content-Type: text/plain; charset=us-ascii

> > 2b5f5024728c ("openvpn: Use correct error value in VPN agent credential
> > reply")
> >
> 
> I hardly see that this could be the root cause, we don't use any agent.

I just listed the changes in the range. I agree is this one and the
last one are unlikely the root cause.

> I need to do some filtering before I could provide logs.
> What I have seen is that openvpn was never finished connecting and it
> always says "init_instance" when getting the SIGTERM:
> 
> Jan 10 18:59:31 info connman-vpnd[502]: pid 21413 was not killed, retrying
> after 2 sec
> Jan 10 18:59:31 notice openvpn[21413]: SIGTERM[hard,init_instance]
> received, process exiting
> 
> While the log from a previous stop (after which the VPN was brought up
> again) looks like:
> Jan 10 18:59:22 notice openvpn[820]: SIGTERM[hard,] received, process
> exiting

The task code first issues a kill(pid, 0) after 2 seconds
kill(pid, SIGINT) and if that didn't work after 1 second
a kill(pid, SIGKILL).

After 3 seconds the OpenVPN daemon should be gone. Isn't this the
case?

------------------------------

Date: Wed, 22 Jan 2020 17:17:03 +0100
From: Torstein Husebø <[email protected]>
Subject: [PATCH] Treewide: fix typos
To: [email protected]
Cc: Torstein Husebø <[email protected]>
Message-ID: <[email protected]>

---
 README                               | 4 ++--
 doc/agent-api.txt                    | 6 +++---
 doc/connman-vpn-provider.config.5.in | 2 +-
 doc/connman.conf.5.in                | 2 +-
 doc/connmanctl.1.in                  | 2 +-
 doc/counter-api.txt                  | 4 ++--
 doc/manager-api.txt                  | 2 +-
 doc/overview-api.txt                 | 2 +-
 doc/peer-api.txt                     | 4 ++--
 doc/plugin-api.txt                   | 2 +-
 doc/session-api.txt                  | 2 +-
 doc/session-overview.txt             | 2 +-
 doc/vpn-agent-api.txt                | 2 +-
 doc/vpn-overview.txt                 | 2 +-
 doc/wifi-p2p-overview.txt            | 2 +-
 plugins/ofono.c                      | 6 +++---
 plugins/session_policy_local.c       | 6 +++---
 plugins/tist.c                       | 2 +-
 src/connection.c                     | 2 +-
 src/dnsproxy.c                       | 2 +-
 src/firewall-nftables.c              | 2 +-
 src/inet.c                           | 4 ++--
 src/iptables.c                       | 8 ++++----
 src/network.c                        | 2 +-
 src/notifier.c                       | 2 +-
 src/provider.c                       | 4 ++--
 src/service.c                        | 8 ++++----
 src/stats.c                          | 8 ++++----
 src/task.c                           | 4 ++--
 src/timeserver.c                     | 2 +-
 test/test-session                    | 2 +-
 vpn/plugins/openconnect.c            | 4 ++--
 vpn/plugins/openvpn.c                | 2 +-
 vpn/plugins/vpn.c                    | 2 +-
 vpn/vpn-provider.c                   | 4 ++--
 35 files changed, 58 insertions(+), 58 deletions(-)

diff --git a/README b/README
index d79a0bc7c2..e911bc2d6b 100644
--- a/README
+++ b/README
@@ -278,7 +278,7 @@ If timing conditions are relevant then it is recommended 
command to
 get log traces as follows:
     connmand -d 2>&1 | ts '[%H:%M:%.S]' | tee connman.log
 
-The 'ts' program is normaly avialable in the moreutils package.
+The 'ts' program is normally available in the moreutils package.
 
 
 Kernel configuration
@@ -427,7 +427,7 @@ the online check request (example):
        Connection: close
 
 Currently following information is returned from connman.net if
-the connection is successfull (200 OK http response code is returned):
+the connection is successful (200 OK http response code is returned):
        Server: nginx
        Date: Mon, 09 Jun 2014 09:25:42 GMT
        Content-Type: text/html
diff --git a/doc/agent-api.txt b/doc/agent-api.txt
index e3c1dcde8c..b2becd2a5a 100644
--- a/doc/agent-api.txt
+++ b/doc/agent-api.txt
@@ -36,7 +36,7 @@ Methods               void Release()
                void RequestBrowser(object service, string url)
 
                        This method gets called when it is required
-                       to ask the user to open a website to procceed
+                       to ask the user to open a website to proceed
                        with login handling.
 
                        This can happen if connected to a hotspot portal
@@ -54,7 +54,7 @@ Methods               void Release()
                        keys are the field names and the values are the
                        actual fields. Alternatively an error indicating that
                        the request got canceled can be returned.
-                       OperationAborted will be return on a successfull
+                       OperationAborted will be return on a successful
                        cancel request.
 
                        Most common return field names are "Name" and of
@@ -121,7 +121,7 @@ Fields              string Name
                string PreviousPassphrase
 
                        The previous passphrase successfully saved, i.e.
-                       which led to a successfull connection. This field is
+                       which led to a successful connection. This field is
                        provided as an informational argument when connecting
                        with it does not work anymore, for instance when it
                        has been changed on the AP. Such argument appears when
diff --git a/doc/connman-vpn-provider.config.5.in 
b/doc/connman-vpn-provider.config.5.in
index 51d547b347..cea99e65dc 100644
--- a/doc/connman-vpn-provider.config.5.in
+++ b/doc/connman-vpn-provider.config.5.in
@@ -12,7 +12,7 @@ connection_name.config \- ConnMan vpn connection provisioning 
file
 \fIConnMan\fP's vpn connections are configured with so called
 "\fBprovisioning files\fP" which reside under \fI@vpn_storagedir@/\fP.
 The files can be named anything, as long as they contain only printable
-ascii characers, for example letters, numbers and underscores. The file
+ascii characters, for example letters, numbers and underscores. The file
 must end with \fB.config\fP. Each VPN connection requires a provisioning
 file, but multiple connections can be specified in the same file.
 .SH "FILE FORMAT"
diff --git a/doc/connman.conf.5.in b/doc/connman.conf.5.in
index e42b22f0f6..a90c2291fe 100644
--- a/doc/connman.conf.5.in
+++ b/doc/connman.conf.5.in
@@ -87,7 +87,7 @@ technology even if not setup and saved to storage.
 List of technoolgies which are always connected regardless
 of PreferredTechnologies setting (AutoConnect = true). The
 default value is empty and this feature is disabled unless
-explicitely enabled in the config file.
+explicitly enabled in the config file.
 .TP
 .BI PreferredTechnologies= technology\fR[,...]
 List of preferred technologies from the most preferred
diff --git a/doc/connmanctl.1.in b/doc/connmanctl.1.in
index 47d9c30378..d87472c32d 100644
--- a/doc/connmanctl.1.in
+++ b/doc/connmanctl.1.in
@@ -47,7 +47,7 @@ Shows the abbreviated help menu in the terminal.
 .PP
 .TP
 .B state
-Shows the system properties. Includes ths online state of the
+Shows the system properties. Includes the online state of the
 system, offline mode, and session mode.
 .PP
 .TP
diff --git a/doc/counter-api.txt b/doc/counter-api.txt
index 32411d5797..c0d9b76954 100644
--- a/doc/counter-api.txt
+++ b/doc/counter-api.txt
@@ -47,12 +47,12 @@ Methods             void Release()
 
                                RX.Errors
 
-                                       Total number of erronous packets
+                                       Total number of erroneous packets
                                        received.
 
                                TX.Errors
 
-                                       Total number of erronous packets
+                                       Total number of erroneous packets
                                        sent.
 
                                RX.Dropped
diff --git a/doc/manager-api.txt b/doc/manager-api.txt
index bfb07bd310..6eaa0a38a4 100644
--- a/doc/manager-api.txt
+++ b/doc/manager-api.txt
@@ -149,7 +149,7 @@ Methods             dict GetProperties()
                        creation of a tun/tap interface, and IP
                        configuration, NAT and IP forwarding on that
                        interface.
-                       An object path, a dictionnary and a file descriptor
+                       An object path, a dictionary and a file descriptor
                        with IP settings are returned.
 
                        Possible Errors: [service].Error.InvalidArguments
diff --git a/doc/overview-api.txt b/doc/overview-api.txt
index fd51d7062b..d7f9d89761 100644
--- a/doc/overview-api.txt
+++ b/doc/overview-api.txt
@@ -214,7 +214,7 @@ with spaces.
 
 In addition to WiFi naming, WiFi networks are subject to a grouping policy
 performed around SSID and security type. This means that one service will be
-seen for N WiFi networks providing the same SSID and the same security metod.
+seen for N WiFi networks providing the same SSID and the same security method.
 For instance, if 5 APs are servicing an SSID called "TEST" with WPA2
 authentication and 3 APs are servicing the same SSID with open authentication
 method, the user will see only two services listed with the name "TEST"
diff --git a/doc/peer-api.txt b/doc/peer-api.txt
index cc094ff251..5256c5ee91 100644
--- a/doc/peer-api.txt
+++ b/doc/peer-api.txt
@@ -98,5 +98,5 @@ Properties    string State [readonly] [experimental]
 
                        array{byte} WiFiDisplayIEs [readonly]
 
-                               The TLV formated byte array representing the
-                               WiFi Display Informations Elements.
+                               The TLV formatted byte array representing the
+                               WiFi Display Information Elements.
diff --git a/doc/plugin-api.txt b/doc/plugin-api.txt
index 36391e961b..8a6e0e84ab 100644
--- a/doc/plugin-api.txt
+++ b/doc/plugin-api.txt
@@ -157,7 +157,7 @@ associate the new Network with the existing Device entity 
(the local Bluetooth
 Adapter).
 
 Then in the vtable's connect method all the needed pieces to perform a
-connection shall be perfomed.
+connection shall be performed.
 
 To learn how to use the connman_network_*() functions such as
 connman_network_set_index() and connman_network_set_connected() see
diff --git a/doc/session-api.txt b/doc/session-api.txt
index 46ac5f3dc9..8bfcf6b053 100644
--- a/doc/session-api.txt
+++ b/doc/session-api.txt
@@ -140,7 +140,7 @@ Settings    string State [readonly]
                        The services are sorted in the order of the bearer
                        entries in this list.
 
-                       Also "*" matches any bearer. This is usefull to prefer
+                       Also "*" matches any bearer. This is useful to prefer
                        certain bearers such as 'wifi' with a fallback to any
                        other available bearer.
 
diff --git a/doc/session-overview.txt b/doc/session-overview.txt
index 976c351826..70dd9ee293 100644
--- a/doc/session-overview.txt
+++ b/doc/session-overview.txt
@@ -26,7 +26,7 @@ behind this is that a session doesn't request a connection 
for itself
 instead waits until another session actively requires to go online.
 This is comparable to piggy-backing.
 
-Connnect()
+Connect()
  +------+
  |      v
 +------------+
diff --git a/doc/vpn-agent-api.txt b/doc/vpn-agent-api.txt
index 23567518f3..ffa6fadd04 100644
--- a/doc/vpn-agent-api.txt
+++ b/doc/vpn-agent-api.txt
@@ -134,7 +134,7 @@ Fields              string Username
                        is set "true") or clear ("Value" is set "false") the
                        credentials or not. "Requirement" should be set to
                        "control". By default this is not required to be set
-                       and is handled only when explicitely defined as "true".
+                       and is handled only when explicitly defined as "true".
                        This is useful in case of having both the
                        AllowStoreCredentials and the AllowRetrieveCredentials
                        set as "false", but clearing credentials is not
diff --git a/doc/vpn-overview.txt b/doc/vpn-overview.txt
index 3a08e45118..d2d14a0c8f 100644
--- a/doc/vpn-overview.txt
+++ b/doc/vpn-overview.txt
@@ -54,7 +54,7 @@ is established (meaning VPN client has managed to create a 
connection
 to VPN server), then State property is set to "ready" and PropertyChanged
 signal is sent. If the connection cannot be established, then
 State property is set to "failure".
-After successfull connection, the relevant connection properties are sent
+After successful connection, the relevant connection properties are sent
 by PropertyChanged signal; like IPv[4|6] information, the index of the
 VPN tunneling interface (if there is any), nameserver information,
 server specified routes etc.
diff --git a/doc/wifi-p2p-overview.txt b/doc/wifi-p2p-overview.txt
index 73b677c553..3dbee7e4d2 100644
--- a/doc/wifi-p2p-overview.txt
+++ b/doc/wifi-p2p-overview.txt
@@ -37,7 +37,7 @@ The UI willing to access to WiFi P2P technology should 
proceed this way:
 Internals
 =========
 
-Through such API, everything is made to hide irrelevant informations for the
+Through such API, everything is made to hide irrelevant information for the
 applications, which are:
 
 - Everything related to the P2P group and the Group Owner (GO)
diff --git a/plugins/ofono.c b/plugins/ofono.c
index 82413b6e68..36873d5a0c 100644
--- a/plugins/ofono.c
+++ b/plugins/ofono.c
@@ -614,7 +614,7 @@ static void context_set_active_reply(struct modem_data 
*modem,
        if (success) {
                /*
                 * Don't handle do anything on success here. oFono will send
-                * the change via PropertyChanged singal.
+                * the change via PropertyChanged signal.
                 */
                return;
        }
@@ -667,7 +667,7 @@ static void cdma_cm_set_powered_reply(struct modem_data 
*modem,
        if (success) {
                /*
                 * Don't handle do anything on success here. oFono will send
-                * the change via PropertyChanged singal.
+                * the change via PropertyChanged signal.
                 */
                return;
        }
@@ -2968,7 +2968,7 @@ static void ofono_exit(void)
 
        if (modem_hash) {
                /*
-                * We should propably wait for the SetProperty() reply
+                * We should probably wait for the SetProperty() reply
                 * message, because ...
                 */
                g_hash_table_foreach(modem_hash, modem_power_down, NULL);
diff --git a/plugins/session_policy_local.c b/plugins/session_policy_local.c
index 9beb0980e6..32b9c69797 100644
--- a/plugins/session_policy_local.c
+++ b/plugins/session_policy_local.c
@@ -66,7 +66,7 @@ static GHashTable *gid_hash;     /* (gid, policy_group) */
 struct policy_file {
        /*
         * A valid file is a keyfile with one ore more groups. All
-        * groups are keept in this list.
+        * groups are kept in this list.
         */
        GSList *groups;
 };
@@ -134,7 +134,7 @@ static char *parse_selinux_type(const char *context)
 
        /*
         * SELinux combines Role-Based Access Control (RBAC), Type
-        * Enforcment (TE) and optionally Multi-Level Security (MLS).
+        * Enforcement (TE) and optionally Multi-Level Security (MLS).
         *
         * When SELinux is enabled all processes and files are labeled
         * with a contex that contains information such as user, role
@@ -145,7 +145,7 @@ static char *parse_selinux_type(const char *context)
         *
         * For identifyng application we (ab)using the type
         * information. In the above example the haifux_exec_t type
-        * will be transfered to haifux_t as defined in the domain
+        * will be transferred to haifux_t as defined in the domain
         * transition and thus we are able to identify the application
         * as haifux_t.
         */
diff --git a/plugins/tist.c b/plugins/tist.c
index cc2800a1ad..c3a5e6945b 100644
--- a/plugins/tist.c
+++ b/plugins/tist.c
@@ -578,7 +578,7 @@ static int tist_init(void)
 
                err = install_ldisc(install_channel, true);
                if (err < 0) {
-                       connman_error("ldisc installtion failed");
+                       connman_error("ldisc installation failed");
                        return err;
                }
        }
diff --git a/src/connection.c b/src/connection.c
index bc8dcb2c38..303e99223a 100644
--- a/src/connection.c
+++ b/src/connection.c
@@ -971,7 +971,7 @@ void __connman_connection_gateway_remove(struct 
connman_service *service,
                        data->ipv6_gateway, do_ipv6);
 
        /* with vpn this will be called after the network was deleted,
-        * we need to call set_default here because we will not recieve any
+        * we need to call set_default here because we will not receive any
         * gateway delete notification.
         * We hit the same issue if remove_gateway() fails.
         */
diff --git a/src/dnsproxy.c b/src/dnsproxy.c
index bd1c0c7e3c..a7bf87a144 100644
--- a/src/dnsproxy.c
+++ b/src/dnsproxy.c
@@ -453,7 +453,7 @@ static void send_cached_response(int sk, unsigned char 
*buf, int len,
        hdr->nscount = 0;
        hdr->arcount = 0;
 
-       /* if this is a negative reply, we are authorative */
+       /* if this is a negative reply, we are authoritative */
        if (answers == 0)
                hdr->aa = 1;
        else
diff --git a/src/firewall-nftables.c b/src/firewall-nftables.c
index 8815c29cb7..d73d661fb9 100644
--- a/src/firewall-nftables.c
+++ b/src/firewall-nftables.c
@@ -22,7 +22,7 @@
 /*
  * This file is based on the libnftnl examples:
  *   https://git.netfilter.org/libnftnl/tree/examples
- * by Pablo Neira Ayuso. and inspiration from systemd nft implemention
+ * by Pablo Neira Ayuso. and inspiration from systemd nft implementation
  *   
https://github.com/zonque/systemd/blob/rfc-nftnl/src/shared/firewall-util.c
  * by Daniel Mack.
  */
diff --git a/src/inet.c b/src/inet.c
index c06f0df7d7..99520e3217 100644
--- a/src/inet.c
+++ b/src/inet.c
@@ -3226,7 +3226,7 @@ static int get_nfs_server_ip(const char *cmdline_file, 
const char *pnp_file,
        if (cmdline[len - 1] == '\n')
                cmdline[--len] = '\0';
 
-       /* split in arguments (seperated by space) */
+       /* split in arguments (separated by space) */
        args = g_strsplit(cmdline, " ", 0);
        if (!args) {
                connman_error("%s: Cannot split cmdline \"%s\"\n", __func__,
@@ -3429,7 +3429,7 @@ char **__connman_inet_get_pnp_nameservers(const char 
*pnp_file)
        }
 
        /*
-        * Perform two passes to retreive a char ** array of
+        * Perform two passes to retrieve a char ** array of
         * nameservers that are not 0.0.0.0
         *
         * The first pass counts them, the second fills in the
diff --git a/src/iptables.c b/src/iptables.c
index 9cfd80f865..47ea1c2d97 100644
--- a/src/iptables.c
+++ b/src/iptables.c
@@ -62,7 +62,7 @@
  * - ipt_entry->target_offset =  Size of ipt_entry + matches
  * - ipt_entry->next_offset =  Size of ipt_entry + matches + target
  * - IPT_SO_SET_REPLACE is used to write a table (contains the complete
- * - hook_entry and overflow mark the begining and the end of a chain, e.g
+ * - hook_entry and overflow mark the beginning and the end of a chain, e.g
  *     entry hook: pre/in/fwd/out/post -1/0/352/504/-1
  *     underflow:  pre/in/fwd/out/post -1/200/352/904/-1
  *   means that INPUT starts at offset 0 and ends at 200 (the start offset to
@@ -868,7 +868,7 @@ static int iptables_add_entry(struct connman_iptables 
*table,
        entry_before = before->data;
 
        /*
-        * We've just appended/insterted a new entry. All references
+        * We've just appended/inserted a new entry. All references
         * should be bumped accordingly.
         */
        update_targets_reference(table, entry_before, e, false);
@@ -3231,7 +3231,7 @@ static int parse_rule_spec(struct connman_iptables *table,
         *  - if '!' is found, set the invert flag to true and
         *    removes the '!' from the optarg string and jumps
         *    back to getopt to reparse the current optarg string.
-        *    After reparsing the invert flag is reseted to false.
+        *    After reparsing the invert flag is reset to false.
         *  - If 'm' or 'j' is found then call either
         *    prepare_matches() or prepare_target(). Those function
         *    will modify (extend) the longopts for getopt_long.
@@ -3499,7 +3499,7 @@ static int parse_rule_spec(struct connman_iptables *table,
                                optarg[0] = '\0';
 
                                /*
-                                * And recall getopt_long without reseting
+                                * And recall getopt_long without resetting
                                 * invert.
                                 */
                                continue;
diff --git a/src/network.c b/src/network.c
index 56fe24ffb5..f2ab16bd26 100644
--- a/src/network.c
+++ b/src/network.c
@@ -1253,7 +1253,7 @@ static void network_destruct(struct connman_network 
*network)
 
 /**
  * connman_network_create:
- * @identifier: network identifier (for example an unqiue name)
+ * @identifier: network identifier (for example an unique name)
  *
  * Allocate a new network and assign the #identifier to it.
  *
diff --git a/src/notifier.c b/src/notifier.c
index 47eb72f174..a39d54c7a6 100644
--- a/src/notifier.c
+++ b/src/notifier.c
@@ -241,7 +241,7 @@ void __connman_notifier_service_remove(struct 
connman_service *service)
 
        if (g_hash_table_lookup(service_hash, service)) {
                /*
-                * This is a tempory check for consistency. It can be
+                * This is a temporary check for consistency. It can be
                 * removed when there are no reports for the following
                 * error message.
                 */
diff --git a/src/provider.c b/src/provider.c
index 7de96643c5..7d663e0c15 100644
--- a/src/provider.c
+++ b/src/provider.c
@@ -492,7 +492,7 @@ void connman_provider_set_index(struct connman_provider 
*provider, int index)
 
                ipconfig = __connman_service_get_ip4config(service);
                if (!ipconfig) {
-                       DBG("Couldnt create ipconfig");
+                       DBG("Couldn't create ipconfig");
                        goto done;
                }
        }
@@ -507,7 +507,7 @@ void connman_provider_set_index(struct connman_provider 
*provider, int index)
 
                ipconfig = __connman_service_get_ip6config(service);
                if (!ipconfig) {
-                       DBG("Couldnt create ipconfig for IPv6");
+                       DBG("Couldn't create ipconfig for IPv6");
                        goto done;
                }
        }
diff --git a/src/stats.c b/src/stats.c
index 6f7ce20886..1df41f1476 100644
--- a/src/stats.c
+++ b/src/stats.c
@@ -53,7 +53,7 @@
  *
  * File properties:
  *   The ring buffer is mmap to a file
- *   Initialy only the smallest possible amount of disk space is allocated
+ *   Initially only the smallest possible amount of disk space is allocated
  *   The files grow to the configured maximal size
  *   The grows by _SC_PAGESIZE step size
  *   For each service a file is created
@@ -80,8 +80,8 @@
  *
  * History file:
  *   Same format as the ring buffer file
- *   For a period of at least 2 months dayly records are keept
- *   If older, then only a monthly record is keept
+ *   For a period of at least 2 months daily records are kept
+ *   If older, then only a monthly record is kept
  */
 
 
@@ -348,7 +348,7 @@ static int stats_open_temp(struct stats_file *file)
                                        STORAGEDIR);
        file->fd = g_mkstemp_full(file->name, O_RDWR | O_CREAT, 0644);
        if (file->fd < 0) {
-               connman_error("create tempory file error %s for %s",
+               connman_error("create temporary file error %s for %s",
                                strerror(errno), file->name);
                g_free(file->name);
                file->name = NULL;
diff --git a/src/task.c b/src/task.c
index 8947cc4314..280b5e4c99 100644
--- a/src/task.c
+++ b/src/task.c
@@ -138,7 +138,7 @@ struct connman_task *connman_task_create(const char 
*program,
  * connman_task_destory:
  * @task: task structure
  *
- * Remove and destory #task
+ * Remove and destroy #task
  */
 void connman_task_destroy(struct connman_task *task)
 {
@@ -228,7 +228,7 @@ int connman_task_add_variable(struct connman_task *task,
 /**
  * connman_task_set_notify:
  * @task: task structure
- * @member: notifcation method name
+ * @member: notification method name
  * @function: notification callback
  * @user_data: optional notification user data
  *
diff --git a/src/timeserver.c b/src/timeserver.c
index 9832c2a5e5..decca153d1 100644
--- a/src/timeserver.c
+++ b/src/timeserver.c
@@ -328,7 +328,7 @@ static void ts_recheck_enable(void)
 }
 
 /*
- * This function must be called everytime the default service changes, the
+ * This function must be called every time the default service changes, the
  * service timeserver(s) or gateway changes or the global timeserver(s) 
changes.
  */
 int __connman_timeserver_sync(struct connman_service *default_service)
diff --git a/test/test-session b/test/test-session
index 2d82fb65ea..bef4b6b8e0 100755
--- a/test/test-session
+++ b/test/test-session
@@ -138,7 +138,7 @@ class SessionApplication(dbus.service.Object):
 
                s = self.find_session(session_name)
                if s and s['session'] :
-                       print "Session %s already created-> drop reqest" % 
(session_name)
+                       print "Session %s already created-> drop request" % 
(session_name)
                        return
 
                try:
diff --git a/vpn/plugins/openconnect.c b/vpn/plugins/openconnect.c
index e0501bb856..d600e61e4b 100644
--- a/vpn/plugins/openconnect.c
+++ b/vpn/plugins/openconnect.c
@@ -886,7 +886,7 @@ static int run_connect(struct oc_private_data *data)
        /*
         * To clarify complex situation, if cookie is expected to be printed
         * to stdout all other output must go to syslog. But with PKCS all
-        * output must be catched in order to get message about file decryption
+        * output must be caught in order to get message about file decryption
         * error. For this reason, the mode has to be interactive as well.
         */
        switch (data->connect_type) {
@@ -1537,7 +1537,7 @@ static int oc_error_code(struct vpn_provider *provider, 
int exit_code)
 {
        connman_info("%d", exit_code);
 
-       /* OpenConnect process return values are ambigious in definition
+       /* OpenConnect process return values are ambiguous in definition
         * https://github.com/openconnect/openconnect/blob/master/main.c#L1693
         * and it is safer not to rely on them. Login error cannot be
         * differentiated from connection errors, e.g., when self signed
diff --git a/vpn/plugins/openvpn.c b/vpn/plugins/openvpn.c
index 262e1088a9..e5d9d943c7 100644
--- a/vpn/plugins/openvpn.c
+++ b/vpn/plugins/openvpn.c
@@ -501,7 +501,7 @@ static int run_connect(struct ov_private_data *data,
         * moment. The problem is that when OpenVPN decides to switch
         * from CONNECTED state to RECONNECTING and then to RESOLVE,
         * it is not possible to do a DNS lookup. The DNS server is
-        * not accessable through the tunnel anymore and so we end up
+        * not accessible through the tunnel anymore and so we end up
         * trying to resolve the OpenVPN servers address.
         */
        connman_task_add_argument(task, "--ping-restart", "0");
diff --git a/vpn/plugins/vpn.c b/vpn/plugins/vpn.c
index e4d0463565..e04670c85d 100644
--- a/vpn/plugins/vpn.c
+++ b/vpn/plugins/vpn.c
@@ -290,7 +290,7 @@ static DBusMessage *vpn_notify(struct connman_task *task,
                         * We need to remove first the old address, just
                         * replacing the old address will not work as expected
                         * because the old address will linger in the interface
-                        * and not disapper so the clearing is needed here.
+                        * and not disappear so the clearing is needed here.
                         *
                         * Also the state must change, otherwise the routes
                         * will not be set properly.
diff --git a/vpn/vpn-provider.c b/vpn/vpn-provider.c
index 53131cce5e..fd5fd91078 100644
--- a/vpn/vpn-provider.c
+++ b/vpn/vpn-provider.c
@@ -2739,7 +2739,7 @@ void vpn_provider_set_index(struct vpn_provider 
*provider, int index)
                provider->ipconfig_ipv4 = __vpn_ipconfig_create(index,
                                                                AF_INET);
                if (!provider->ipconfig_ipv4) {
-                       DBG("Couldnt create ipconfig for IPv4");
+                       DBG("Couldn't create ipconfig for IPv4");
                        goto done;
                }
        }
@@ -2750,7 +2750,7 @@ void vpn_provider_set_index(struct vpn_provider 
*provider, int index)
                provider->ipconfig_ipv6 = __vpn_ipconfig_create(index,
                                                                AF_INET6);
                if (!provider->ipconfig_ipv6) {
-                       DBG("Couldnt create ipconfig for IPv6");
+                       DBG("Couldn't create ipconfig for IPv6");
                        goto done;
                }
        }
diff --git a/src/service.c b/src/service.c
index 4d1235e3cf..2f497d10ce 100644
--- a/src/service.c
+++ b/src/service.c
@@ -43,7 +43,7 @@
 
 #define VPN_AUTOCONNECT_TIMEOUT_DEFAULT 1
 #define VPN_AUTOCONNECT_TIMEOUT_STEP 30
-#define VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_TRESHOLD 270
+#define VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_THRESHOLD 270
 
 static DBusConnection *connection = NULL;
 
@@ -4334,13 +4334,13 @@ static gboolean run_vpn_auto_connect(gpointer data) {
                goto out;
        }
 
-       /* Increase the attempt count up to the treshold.*/
-       if (attempts < VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_TRESHOLD)
+       /* Increase the attempt count up to the threshold.*/
+       if (attempts < VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_THRESHOLD)
                attempts++;
 
        /*
         * Timeout increases with 1s after VPN_AUTOCONNECT_TIMEOUT_STEP amount
         * of attempts made. After VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_TRESHOLD is
         * reached the delay does not increase.
         */
        timeout = timeout + (int)(attempts / VPN_AUTOCONNECT_TIMEOUT_STEP);
@@ -4334,13 +4334,13 @@ static gboolean run_vpn_auto_connect(gpointer data) {
        /*
         * Timeout increases with 1s after VPN_AUTOCONNECT_TIMEOUT_STEP amount
-        * of attempts made. After VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_TRESHOLD is
+        * of attempts made. After VPN_AUTOCONNECT_TIMEOUT_ATTEMPTS_THRESHOLD is
         * reached the delay does not increase.
         */
-- 
2.25.0

------------------------------

Subject: Digest Footer

_______________________________________________
connman mailing list -- [email protected]
To unsubscribe send an email to [email protected]


------------------------------

End of connman Digest, Vol 51, Issue 28
***************************************

Reply via email to